@@ -11,6 +11,8 @@
 #include <unistd.h>
 
 #include "blaze822.h"
+#include "blaze822_priv.h"
+#include "xpledge.h"
 
 static int qflag;
 static int status;
@@ -35,10 +37,9 @@ inc(char *dir)
 	}
 
 	while ((d = readdir(fd))) {
-#if defined(DT_REG) && defined(DT_UNKNOWN)
-		if (d->d_type != DT_REG && d->d_type != DT_UNKNOWN)
+		if (!MAIL_DT(d->d_type))
 			continue;
-#endif
+
 		if (d->d_name[0] == '.')
 			continue;
 
@@ -76,6 +77,8 @@ usage:
 	if (optind == argc)
 		goto usage;
 
+	xpledge("stdio rpath cpath", "");
+
 	status = 0;
 	for (i = optind; i < argc; i++)
 		inc(argv[i]);
