@@ -110,15 +110,14 @@ blaze822_seq_load(char *map)
 		char *e = t;
 		while (s < e && isfws(*(e-1)))
 			e--;
-//		printf("{%.*s}\n", e-s, s);
 		char *f = strndup(s, e-s);
 		if (!f)
 			return -1;
 
-		struct msgnum key, **result;
+		struct msgnum key;
 		key.file = f;
 
-		if (!(result = tfind(&key, &msgnums, msgnumorder))) {
+		if (!tfind(&key, &msgnums, msgnumorder)) {
 			struct msgnum *c = malloc(sizeof (struct msgnum));
 			c->file = f;
 			c->pos = line;
@@ -152,6 +151,9 @@ blaze822_seq_cur(void)
 int
 blaze822_seq_setcur(char *s)
 {
+	if (strcmp(s, "/dev/stdin") == 0)
+		return 0;
+
 	char *override = getenv("MAILDOT");
 	if (override)
 		return 0;
@@ -181,7 +183,7 @@ parse_relnum(char *a, long cur, long start, long last, long *out)
 
 	if (strcmp(a, "+") == 0)
 		a = ".+1";
-	else if (strcmp(a, "-") == 0)
+	else if (strcmp(a, ".-") == 0)
 		a = ".-1";
 	else if (strcmp(a, ".") == 0)
 		a = ".+0";
@@ -394,7 +396,6 @@ find_cur(char *map, struct blaze822_seq_iter *iter)
 		while (*s == ' ' || *s == '\t')
 			s++;
 
-//		printf("{%.*s}\n", t-s, s);
 		iter->lines++;
 		if (!cur && curfile &&
 		    strncmp(s, curfile, strlen(curfile)) == 0 &&
@@ -426,7 +427,7 @@ blaze822_seq_next(char *map, char *range, struct blaze822_seq_iter *iter)
 	if (!iter->lines)  // count total lines
 		find_cur(map, iter);
 
-	if (!iter->start) {
+	if (!iter->s) {
 		int ret = parse_range(map, range, &iter->start, &iter->stop,
 		    iter->cur, iter->lines);
 		if (ret == 1) {
@@ -501,12 +502,8 @@ iterdir(char *dir, void (*cb)(char *))
 
 	long i = 0;
 	for (i = 0; i < n; i++) {
-		if (namelist[i]->d_name[0] != '.')
-#if defined(DT_REG) && defined(DT_UNKNOWN)
-		if (namelist[i]->d_type == DT_REG ||
-		    namelist[i]->d_type == DT_UNKNOWN)
-#endif
-		{
+		if (namelist[i]->d_name[0] != '.' &&
+		    MAIL_DT(namelist[i]->d_type)) {
 			snprintf(sub, sizeof sub, "%s%s/%s",
 			    dir, m, namelist[i]->d_name);
 			cb(sub);
@@ -539,16 +536,24 @@ blaze822_loop(int argc, char *argv[], void (*cb)(char *))
 
 	char *map = 0;
 	int map_opened = 0;
-	struct blaze822_seq_iter iter = { 0 };
 	int j = 0;
 	for (i = 0; i < argc; i++) {
 		if (strchr(argv[i], '/')) {  // a file name
 			j += iterdir(argv[i], cb);
+		} else if (strcmp(argv[i], "-") == 0) {
+			if (isatty(0)) {
+				fprintf(stderr, "mblaze: warning: - now means "
+				    "read mail text from standard input, "
+				    "use .- to refer to previous mail\n");
+			}
+			cb("/dev/stdin");
+			j++;
 		} else {
 			if (!map_opened) {
 				map = blaze822_seq_open(0);
 				map_opened = 1;
 			}
+			struct blaze822_seq_iter iter = { 0 };
 			while ((line = blaze822_seq_next(map, argv[i], &iter))) {
 				cb(line);
 				free(line);
